@@ -2,7 +2,7 @@
  * vi: set autoindent tabstop=4 shiftwidth=4 :
  *
  * Copyright (c) 2002-2006 MontaVista Software, Inc.
- * Copyright (c) 2006 Sun Microsystems, Inc.
+ * Copyright (c) 2006-2008 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -54,8 +54,8 @@
 #include <assert.h>
 
 #include <saAis.h>
-#include <ipc_gen.h>
-#include <ais_util.h>
+#include <corosync/ipc_gen.h>
+#include "util.h"
 
 enum SA_HANDLE_STATE {
 	SA_HANDLE_STATE_EMPTY,
@@ -83,9 +83,9 @@ struct saHandle {
 #endif
 
 #ifdef OPENAIS_LINUX
-static char *socketname = "libais.socket";
+static char *socketname = "libcorosync.socket";
 #else
-static char *socketname = "/var/run/libais.socket";
+static char *socketname = "/var/run/libcorosync.socket";
 #endif
 
 #ifdef SO_NOSIGPIPE
@@ -546,7 +546,7 @@ saHandleCreate (
 {
 	uint32_t handle;
 	uint32_t check;
-	void *newHandles;
+	void *newHandles = NULL;
 	int found = 0;
 	void *instance;
 	int i;
