@@ -1,6 +1,6 @@
+
 /*
  * Copyright (c) 2002-2003 MontaVista Software, Inc.
- * Copyright (c) 2006-2007 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -40,7 +40,7 @@
 #include <sys/poll.h>
 #include <sys/socket.h>
 
-#include "../include/ipc_gen.h"
+#include <corosync/ipc_gen.h>
 
 /* Debug macro
  */
